query_xc has been deprecated. Use the package
suwo instead: suwo::query_xenocanto()
retrieves 'Xeno-Canto' metadata and suwo::download_media() downloads the recordings.
Details
This function has been deprecated as access to 'Xeno-Canto' (and other online nature media repositories such as Macaulay Library, iNaturalist, GBIF and WikiAves) is now provided by the package suwo. Note that 'Xeno-Canto' queries now require an API key (see ?suwo::query_xenocanto). For example:
Author
Marcelo Araya-Salas (marcelo.araya@ucr.ac.cr)